/* 
 * server auth
 *
 * $Id: servauth.h 762 2008-07-23 02:14:59Z jon13 $
 *
 * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
 */

#ifndef SERVAUTH_H_INCLUDED
#define SERVAUTH_H_INCLUDED

#include "conqdef.h"
#include "datatypes.h"
#include "protocol.h"

int Authenticate(char *name, char *password);


#endif /* SERVAUTH_H_INCLUDED */
